@@ -138,7 +138,7 @@ public final class CreateMultiWidgetsForm
         // set the field value
         textBox.setValue("Sample field");
 
-        document.save("MultiWidgetsForm.pdf");
+        document.save("target/MultiWidgetsForm.pdf");
         document.close();
     }
 }
