@@ -164,6 +164,11 @@ public class CreateVisibleSignature2 extends CreateSignatureBase
         FileOutputStream fos = new FileOutputStream(signedFile);
 
         PDDocument doc = PDDocument.load(inputFile);
+
+        // call SigUtils.checkCrossReferenceTable(doc) if Adobe complains
+        // and read https://stackoverflow.com/a/71293901/535646
+        // and https://issues.apache.org/jira/browse/PDFBOX-5382
+
         int accessPermissions = SigUtils.getMDPPermission(doc);
         if (accessPermissions == 1)
         {
@@ -174,7 +179,7 @@ public class CreateVisibleSignature2 extends CreateSignatureBase
         // be careful with such files.
 
         PDSignature signature = null;
-        PDAcroForm acroForm = doc.getDocumentCatalog().getAcroForm();
+        PDAcroForm acroForm = doc.getDocumentCatalog().getAcroForm(null);
         PDRectangle rect = null;
 
         // sign a PDF with an existing empty signature, as created by the CreateEmptySignatureForm example.
@@ -399,7 +404,7 @@ public class CreateVisibleSignature2 extends CreateSignatureBase
 
         PDPageContentStream cs = new PDPageContentStream(doc, appearanceStream);
 
-        // for 90Â° and 270Â° scale ratio of width / height
+        // for 90° and 270° scale ratio of width / height
         // not really sure about this
         // why does scale have no effect when done in the form matrix???
         if (initialScale != null)
@@ -538,7 +543,9 @@ public class CreateVisibleSignature2 extends CreateSignatureBase
         File ksFile = new File(args[0]);
         KeyStore keystore = KeyStore.getInstance("PKCS12");
         char[] pin = args[1].toCharArray();
-        keystore.load(new FileInputStream(ksFile), pin);
+        InputStream is = new FileInputStream(ksFile);
+        keystore.load(is, pin);
+        is.close();
 
         File documentFile = new File(args[2]);
 
