@@ -346,7 +346,7 @@ public final class CertificateVerifier
                 continue;
             }
             ASN1TaggedObject location = (ASN1TaggedObject) obj.getObjectAt(1);
-            ASN1OctetString uri = (ASN1OctetString) location.getObject();
+            ASN1OctetString uri = (ASN1OctetString) location.getBaseObject();
             String urlString = new String(uri.getOctets());
             InputStream in = null;
             try
@@ -460,7 +460,7 @@ public final class CertificateVerifier
                 if (X509ObjectIdentifiers.id_ad_ocsp.equals(oid)
                         && location.getTagNo() == GeneralName.uniformResourceIdentifier)
                 {
-                    ASN1OctetString url = (ASN1OctetString) location.getObject();
+                    ASN1OctetString url = (ASN1OctetString) location.getBaseObject();
                     String ocspURL = new String(url.getOctets());
                     LOG.info("OCSP URL: " + ocspURL);
                     return ocspURL;
