@@ -31,7 +31,9 @@ import java.security.cert.CertificateEncodingException;
 import java.security.cert.X509CRL;
 import java.security.cert.X509Certificate;
 import java.util.Calendar;
+import java.util.HashMap;
 import java.util.HashSet;
+import java.util.Map;
 import java.util.Set;
 
 import org.apache.commons.logging.Log;
@@ -54,6 +56,7 @@ import org.apache.pdfbox.pdmodel.PDDocumentCatalog;
 import org.apache.pdfbox.pdmodel.encryption.SecurityProvider;
 import org.apache.pdfbox.pdmodel.interactive.digitalsignature.PDSignature;
 import org.apache.pdfbox.util.Hex;
+import org.bouncycastle.asn1.BEROctetString;
 import org.bouncycastle.asn1.ocsp.OCSPObjectIdentifiers;
 import org.bouncycastle.cert.ocsp.BasicOCSPResp;
 import org.bouncycastle.cert.ocsp.OCSPException;
@@ -85,6 +88,7 @@ public class AddValidationInformation
     private COSArray ocsps;
     private COSArray crls;
     private COSArray certs;
+    private final Map<X509Certificate,COSStream> certMap = new HashMap<X509Certificate,COSStream>();
     private PDDocument document;
     private final Set<X509Certificate> foundRevocationInformation = new HashSet<X509Certificate>();
     private Calendar signDate;
@@ -436,7 +440,11 @@ public class AddValidationInformation
         byte[] signatureHash;
         try
         {
-            signatureHash = MessageDigest.getInstance("SHA-1").digest(basicResponse.getSignature());
+            // https://www.etsi.org/deliver/etsi_ts/102700_102799/10277804/01.01.02_60/ts_10277804v010102p.pdf
+            // "For the signatures of the CRL and OCSP response, it is the respective signature
+            // object represented as a BER-encoded OCTET STRING encoded with primitive encoding"
+            BEROctetString encodedSignature = new BEROctetString(basicResponse.getSignature());
+            signatureHash = MessageDigest.getInstance("SHA-1").digest(encodedSignature.getEncoded());
         }
         catch (NoSuchAlgorithmException ex)
         {
@@ -506,7 +514,11 @@ public class AddValidationInformation
             byte[] signatureHash;
             try
             {
-                signatureHash = MessageDigest.getInstance("SHA-1").digest(crl.getSignature());
+                // https://www.etsi.org/deliver/etsi_ts/102700_102799/10277804/01.01.02_60/ts_10277804v010102p.pdf
+                // "For the signatures of the CRL and OCSP response, it is the respective signature
+                // object represented as a BER-encoded OCTET STRING encoded with primitive encoding"
+                BEROctetString berEncodedSignature = new BEROctetString(crl.getSignature());
+                signatureHash = MessageDigest.getInstance("SHA-1").digest(berEncodedSignature.getEncoded());
             }
             catch (NoSuchAlgorithmException ex)
             {
@@ -567,7 +579,7 @@ public class AddValidationInformation
             {
                 COSStream certStream = writeDataToStream(cert.getEncoded());
                 correspondingCerts.add(certStream);
-                certs.add(certStream); // may lead to duplicate certificates. Important?
+                certMap.put(cert, certStream);
             }
             catch (CertificateEncodingException ex)
             {
@@ -588,25 +600,32 @@ public class AddValidationInformation
     }
 
     /**
-     * Adds all certs to the certs-array. Make sure, all certificates are inside the
-     * certificateStore of certInformationHelper
+     * Adds all certs to the certs-array. Make sure that all certificates are inside the
+     * certificateStore of certInformationHelper. This should be the only call to fill certs.
      *
      * @throws IOException
      */
     private void addAllCertsToCertArray() throws IOException
     {
-        try
+        for (X509Certificate cert : certInformationHelper.getCertificateSet())
         {
-            for (X509Certificate cert : certInformationHelper.getCertificateSet())
+            if (!certMap.containsKey(cert))
             {
-                COSStream stream = writeDataToStream(cert.getEncoded());
-                certs.add(stream);
+                try
+                {
+                    COSStream certStream = writeDataToStream(cert.getEncoded());
+                    certMap.put(cert, certStream);
+                }
+                catch (CertificateEncodingException ex)
+                {
+                    throw new IOException(ex);
+                }
             }
         }
-        catch (CertificateEncodingException e)
+        for (COSStream certStream : certMap.values())
         {
-            throw new IOException(e);
-        }
+            certs.add(certStream);
+        }        
     }
 
     /**
@@ -656,7 +675,6 @@ public class AddValidationInformation
 
     public static void main(String[] args) throws IOException, GeneralSecurityException
     {
-//args = new String[]{"C:\\Users\\Tilman\\Downloads\\SO67171648.pdf"};
         if (args.length != 1)
         {
             usage();
