@@ -20,6 +20,7 @@ package org.apache.fontbox.ttf;
 
 import java.io.IOException;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -160,9 +161,7 @@ public class GlyfCompositeDescript extends GlyfDescript
             int n = i - c.getFirstIndex();
             int x = gd.getXCoordinate(n);
             int y = gd.getYCoordinate(n);
-            short x1 = (short) c.scaleX(x, y);
-            x1 += c.getXTranslate();
-            return x1;
+            return (short) (c.scaleX(x, y) + c.getXTranslate());
         }
         return 0;
     }
@@ -180,9 +179,7 @@ public class GlyfCompositeDescript extends GlyfDescript
             int n = i - c.getFirstIndex();
             int x = gd.getXCoordinate(n);
             int y = gd.getYCoordinate(n);
-            short y1 = (short) c.scaleY(x, y);
-            y1 += c.getYTranslate();
-            return y1;
+            return (short) (c.scaleY(x, y) + c.getYTranslate());
         }
         return 0;
     }
@@ -236,7 +233,16 @@ public class GlyfCompositeDescript extends GlyfDescript
         if (contourCount < 0)
         {
             GlyfCompositeComp c = components.get(components.size() - 1);
-            contourCount = c.getFirstContour() + descriptions.get(c.getGlyphIndex()).getContourCount();
+            GlyphDescription gd = descriptions.get(c.getGlyphIndex());
+            if (gd == null)
+            {
+                LOG.error("missing glyph description for index " + c.getGlyphIndex());
+                contourCount = 0;
+            }
+            else
+            {
+                contourCount = c.getFirstContour() + gd.getContourCount();
+            }
         }
         return contourCount;
     }
@@ -251,6 +257,16 @@ public class GlyfCompositeDescript extends GlyfDescript
         return components.size();
     }
 
+    /**
+     * Gets a view to the composite components.
+     * 
+     * @return unmodifiable list of this composite glyph's {@linkplain GlyfCompositeComp components}
+     */
+    public List<GlyfCompositeComp> getComponents()
+    {
+        return Collections.unmodifiableList(components);
+    }
+
     private GlyfCompositeComp getCompositeComp(int i)
     {
         for (GlyfCompositeComp c : components)
