@@ -65,7 +65,18 @@ public class GlyphData
             glyphDescription = new GlyfCompositeDescript(data, glyphTable);
         }
     }
-    
+
+    /**
+     * Initialize an empty glyph record.
+     * 
+     * @throws IOException
+     */
+    void initEmptyData() throws IOException
+    {
+        glyphDescription = new GlyfSimpleDescript();
+        boundingBox = new BoundingBox();
+    }
+
     /**
      * @return Returns the boundingBox.
      */
