@@ -189,60 +189,66 @@ public class TTFParser
             }
         }
         
-        boolean isPostScript = allowCFF() && font.tables.containsKey(CFFTable.TAG);
+        boolean hasCFF = font.tables.containsKey(CFFTable.TAG);
+        boolean isPostScript = allowCFF() && hasCFF;
         
         HeaderTable head = font.getHeader();
         if (head == null)
         {
-            throw new IOException("head is mandatory");
+            throw new IOException("'head' table is mandatory");
         }
 
         HorizontalHeaderTable hh = font.getHorizontalHeader();
         if (hh == null)
         {
-            throw new IOException("hhead is mandatory");
+            throw new IOException("'hhea' table is mandatory");
         }
 
         MaximumProfileTable maxp = font.getMaximumProfile();
         if (maxp == null)
         {
-            throw new IOException("maxp is mandatory");
+            throw new IOException("'maxp' table is mandatory");
         }
 
         PostScriptTable post = font.getPostScript();
         if (post == null && !isEmbedded)
         {
             // in an embedded font this table is optional
-            throw new IOException("post is mandatory");
+            throw new IOException("'post' table is mandatory");
         }
 
         if (!isPostScript)
         {
+            String messageSuffix = "";
+            if (hasCFF)
+            {
+                messageSuffix = "; this an OpenType CFF font, but we expected a TrueType font here";
+            }
             IndexToLocationTable loc = font.getIndexToLocation();
             if (loc == null)
             {
-                throw new IOException("loca is mandatory");
+                throw new IOException("'loca' table is mandatory" + messageSuffix);
             }
 
             if (font.getGlyph() == null)
             {
-                throw new IOException("glyf is mandatory");
+                throw new IOException("'glyf' table is mandatory" + messageSuffix);
             }
         }
 
         if (font.getNaming() == null && !isEmbedded)
         {
-            throw new IOException("name is mandatory");
+            throw new IOException("'name' table is mandatory");
         }
 
         if (font.getHorizontalMetrics() == null)
         {
-            throw new IOException("hmtx is mandatory");
+            throw new IOException("'hmtx' table is mandatory");
         }
         
         if (!isEmbedded && font.getCmap() == null)
         {
-            throw new IOException("cmap is mandatory");
+            throw new IOException("'cmap' table is mandatory");
         }
     }
 
