@@ -30,6 +30,7 @@ import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
+import org.junit.Assume;
 import org.junit.Test;
 
 /**
@@ -133,16 +134,14 @@ public class TTFSubsetterTest
         File simhei = null;
         for (URI uri : files)
         {
-            if (uri.getPath() != null && uri.getPath().toLowerCase(Locale.US).endsWith("simhei.ttf"))
+            String path = uri.getPath();
+            if (path != null && path.toLowerCase(Locale.US).endsWith("simhei.ttf"))
             {
                 simhei = new File(uri);
+                break;
             }
         }
-        if (simhei == null)
-        {
-            System.err.println("SimHei font not available on this machine, test skipped");
-            return;
-        }
+        Assume.assumeTrue("SimHei font not available on this machine, test skipped", simhei != null);
         System.out.println("SimHei font found!");
         TrueTypeFont full = new TTFParser().parse(simhei);
 
