@@ -16,8 +16,10 @@
  */
 package org.apache.pdfbox.contentstream.operator.text;
 
+import java.io.IOException;
 import java.util.List;
 
+import org.apache.pdfbox.contentstream.operator.MissingOperandException;
 import org.apache.pdfbox.cos.COSBase;
 import org.apache.pdfbox.cos.COSNumber;
 import org.apache.pdfbox.contentstream.operator.Operator;
@@ -32,9 +34,18 @@ import org.apache.pdfbox.contentstream.operator.OperatorProcessor;
 public class SetTextLeading extends OperatorProcessor
 {
     @Override
-    public void process(Operator operator, List<COSBase> arguments)
+    public void process(Operator operator, List<COSBase> arguments) throws IOException
     {
-        COSNumber leading = (COSNumber)arguments.get( 0 );
+        if (arguments.isEmpty())
+        {
+            throw new MissingOperandException(operator, arguments);
+        }
+        COSBase base = arguments.get(0);
+        if (!(base instanceof COSNumber))
+        {
+            return;
+        }
+        COSNumber leading = (COSNumber) base;
         context.getGraphicsState().getTextState().setLeading( leading.floatValue() );
     }
 
