@@ -16,7 +16,6 @@
  */
 package org.apache.pdfbox.cos;
 
-import java.io.ByteArrayOutputStream;
 import java.io.Closeable;
 import java.io.FilterOutputStream;
 import java.io.IOException;
@@ -335,8 +334,8 @@ public class COSStream extends COSDictionary implements Closeable
     {
         if (isWriting)
         {
-            throw new IllegalStateException("There is an open OutputStream associated with " +
-                                            "this COSStream. It must be closed before querying" +
+            throw new IllegalStateException("There is an open OutputStream associated with this " +
+                                            "COSStream. It must be closed before querying the " +
                                             "length of this COSStream.");
         }
         return getInt(COSName.LENGTH, 0);
@@ -391,22 +390,23 @@ public class COSStream extends COSDictionary implements Closeable
      */
     public String toTextString()
     {
-        ByteArrayOutputStream out = new ByteArrayOutputStream();
         InputStream input = null;
+        byte[] array;
         try
         {
             input = createInputStream();
-            IOUtils.copy(input, out);
+            array = IOUtils.toByteArray(input);
         }
         catch (IOException e)
         {
+            LOG.debug("An exception occurred trying to get the content - returning empty string instead", e);
             return "";
         }
         finally
         {
             IOUtils.closeQuietly(input);
         }
-        COSString string = new COSString(out.toByteArray());
+        COSString string = new COSString(array);
         return string.getString();
     }
     
@@ -416,6 +416,14 @@ public class COSStream extends COSDictionary implements Closeable
         return visitor.visitFromStream(this);
     }
     
+    /**
+     * {@inheritDoc}
+     *
+     * Called by PDFBox when the PDDocument is closed, this closes the stream and removes the data.
+     * You will usually not need this.
+     *
+     * @throws IOException
+     */
     @Override
     public void close() throws IOException
     {
