@@ -16,7 +16,6 @@
  */
 package org.apache.pdfbox.filter;
 
-import java.io.EOFException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
@@ -72,12 +71,8 @@ final class CCITTFaxFilter extends Filter
             type = TIFFExtension.COMPRESSION_CCITT_T4; // Group 3 1D
             byte[] streamData = new byte[20];
             int bytesRead = encoded.read(streamData);
-            if (bytesRead != streamData.length)
-            {
-                throw new EOFException("Can't read " + streamData.length + " bytes");
-            }
             PushbackInputStream pushbackInputStream = new PushbackInputStream(encoded, streamData.length);
-            pushbackInputStream.unread(streamData);
+            pushbackInputStream.unread(streamData, 0, bytesRead);
             encoded = pushbackInputStream;
             if (streamData[0] != 0 || (streamData[1] >> 4 != 1 && streamData[1] != 1))
             {
@@ -85,7 +80,7 @@ final class CCITTFaxFilter extends Filter
                 // found
                 type = TIFFExtension.COMPRESSION_CCITT_MODIFIED_HUFFMAN_RLE;
                 short b = (short) (((streamData[0] << 8) + (streamData[1] & 0xff)) >> 4);
-                for (int i = 12; i < 160; i++)
+                for (int i = 12; i < bytesRead * 8; i++)
                 {
                     b = (short) ((b << 1) + ((streamData[(i / 8)] >> (7 - (i % 8))) & 0x01));
                     if ((b & 0xFFF) == 1)
