@@ -241,8 +241,16 @@ public abstract class BaseParser
                 }
             }
         }
-        readExpectedChar('>');
-        readExpectedChar('>');
+        try
+        {
+            readExpectedChar('>');
+            readExpectedChar('>');
+        }
+        catch (IOException exception)
+        {
+            LOG.warn("Invalid dictionary, can't find end of dictionary at offset "
+                    + seqSource.getPosition());
+        }
         return obj;
     }
 
@@ -361,8 +369,6 @@ public abstract class BaseParser
      *
      * The second bug was in this format /Title (c:\) /Producer
      *
-     * This patch moves this code out of the parseCOSString method, so it can be used twice.
-     *
      * @param bracesParameter the number of braces currently open.
      *
      * @return the corrected value of the brace counter
@@ -370,29 +376,38 @@ public abstract class BaseParser
      */
     private int checkForEndOfString(final int bracesParameter) throws IOException
     {
-        int braces = bracesParameter;
+        if (bracesParameter == 0)
+        {
+            return 0;
+        }
+        // Check the next 3 bytes if available
         byte[] nextThreeBytes = new byte[3];
         int amountRead = seqSource.read(nextThreeBytes);
-
-        // Check the next 3 bytes if available
         // The following cases are valid indicators for the end of the string
         // 1. Next line contains another COSObject: CR + LF + '/'
         // 2. COSDictionary ends in the next line: CR + LF + '>'
-        // 3. Next line contains another COSObject: CR + '/'
-        // 4. COSDictionary ends in the next line: CR + '>'
-        if (amountRead == 3 && nextThreeBytes[0] == ASCII_CR)
-        {
-            if ( (nextThreeBytes[1] == ASCII_LF && (nextThreeBytes[2] == '/') || nextThreeBytes[2] == '>')
-                    || nextThreeBytes[1] == '/' || nextThreeBytes[1] == '>')
-            {
-                braces = 0;
-            }
-        }
+        // 3. Next line contains another COSObject: LF + '/'
+        // 4. COSDictionary ends in the next line: LF + '>'
+        // 5. Next line contains another COSObject: CR + '/'
+        // 6. COSDictionary ends in the next line: CR + '>'
         if (amountRead > 0)
         {
             seqSource.unread(nextThreeBytes, 0, amountRead);
         }
-        return braces;
+        if (amountRead < 3)
+        {
+            return bracesParameter;
+        }
+        if (((nextThreeBytes[0] == ASCII_CR || nextThreeBytes[0] == ASCII_LF)
+                && (nextThreeBytes[1] == '/' || nextThreeBytes[1] == '>')) //
+                || //
+                (nextThreeBytes[0] == ASCII_CR && nextThreeBytes[1] == ASCII_LF
+                        && (nextThreeBytes[2] == '/' || nextThreeBytes[2] == '>')) //
+        )
+        {
+            return 0;
+        }
+        return bracesParameter;
     }
 
     /**
@@ -937,6 +952,7 @@ public abstract class BaseParser
             {
                 LOG.warn("Skipped unexpected dir object = '" + badString + "' at offset "
                         + seqSource.getPosition() + " (start offset: " + startOffset + ")");
+                return this instanceof PDFStreamParser ? null : COSNull.NULL;
             }
         }
         return null;
