@@ -16,6 +16,8 @@
 package org.apache.pdfbox.pdmodel.common.function;
 
 import java.io.IOException;
+
+import org.apache.pdfbox.cos.COSArray;
 import org.apache.pdfbox.cos.COSBase;
 
 /**
@@ -29,6 +31,7 @@ public class PDFunctionTypeIdentity extends PDFunction
     public PDFunctionTypeIdentity(COSBase function)
     {
         super(null);
+        //TODO passing null is not good because getCOSObject() can result in an NPE in the base class
     }
 
     @Override
@@ -45,6 +48,12 @@ public class PDFunctionTypeIdentity extends PDFunction
         return input;
     }
 
+    @Override
+    protected COSArray getRangeValues()
+    {
+        return null;
+    }
+
     /**
      * {@inheritDoc}
      */
