@@ -17,7 +17,7 @@
 package org.apache.pdfbox.pdmodel.documentinterchange.logicalstructure;
 
 import java.io.IOException;
-import java.util.Hashtable;
+import java.util.HashMap;
 import java.util.Map;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -70,7 +70,12 @@ public class PDStructureTreeRoot extends PDStructureNode
      * Returns the K array entry.
      * 
      * @return the K array entry
+     *
+     * @deprecated use {@link #getK()} only. /K can be a dictionary or an array, and the next level
+     * can also be a dictionary. See file 054080.pdf in PDFBOX-4417 and read "Entries in the
+     * structure tree root" in the PDF specification.
      */
+    @Deprecated
     public COSArray getKArray()
     {
         COSBase k = this.getCOSObject().getDictionaryObject(COSName.K);
@@ -147,7 +152,7 @@ public class PDStructureTreeRoot extends PDStructureNode
         COSBase base = getCOSObject().getDictionaryObject(COSName.PARENT_TREE);
         if (base instanceof COSDictionary)
         {
-            return new PDNumberTreeNode((COSDictionary) base, COSBase.class);
+            return new PDNumberTreeNode((COSDictionary) base, PDParentTreeValue.class);
         }
         return null;
     }
@@ -201,7 +206,7 @@ public class PDStructureTreeRoot extends PDStructureNode
                 LOG.error(e,e);
             }
         }
-        return new Hashtable<String, Object>();
+        return new HashMap<String, Object>();
     }
 
     /**
