@@ -347,19 +347,22 @@ final class FileSystemFontProvider extends FontProvider
                 LOG.trace("Found " + files.size() + " fonts on the local system");
             }
 
-            // load cached FontInfo objects
-            List<FSFontInfo> cachedInfos = loadDiskCache(files);
-            if (cachedInfos != null && !cachedInfos.isEmpty())
+            if (!files.isEmpty())
             {
-                fontInfoList.addAll(cachedInfos);
-            }
-            else
-            {
-                LOG.warn("Building on-disk font cache, this may take a while");
-                scanFonts(files);
-                saveDiskCache();
-                LOG.warn("Finished building on-disk font cache, found " +
-                        fontInfoList.size() + " fonts");
+                // load cached FontInfo objects
+                List<FSFontInfo> cachedInfos = loadDiskCache(files);
+                if (cachedInfos != null && !cachedInfos.isEmpty())
+                {
+                    fontInfoList.addAll(cachedInfos);
+                }
+                else
+                {
+                    LOG.warn("Building on-disk font cache, this may take a while");
+                    scanFonts(files);
+                    saveDiskCache();
+                    LOG.warn("Finished building on-disk font cache, found " + fontInfoList.size()
+                            + " fonts");
+                }
             }
         }
         catch (AccessControlException e)
@@ -398,10 +401,10 @@ final class FileSystemFontProvider extends FontProvider
     private File getDiskCacheFile()
     {
         String path = System.getProperty("pdfbox.fontcache");
-        if (path == null || !new File(path).isDirectory() || !new File(path).canWrite())
+        if (isBadPath(path))
         {
             path = System.getProperty("user.home");
-            if (path == null || !new File(path).isDirectory() || !new File(path).canWrite())
+            if (isBadPath(path))
             {
                 path = System.getProperty("java.io.tmpdir");
             }
@@ -409,6 +412,11 @@ final class FileSystemFontProvider extends FontProvider
         return new File(path, ".pdfbox.cache");
     }
 
+    private static boolean isBadPath(String path)
+    {
+        return path == null || !new File(path).isDirectory() || !new File(path).canWrite();
+    }
+
     /**
      * Saves the font metadata cache to disk.
      */
