@@ -93,10 +93,11 @@ public class PDDeviceN extends PDSpecialColorSpace
         {
             attributes = new PDDeviceNAttributes((COSDictionary)array.getObject(DEVICEN_ATTRIBUTES));
         }
-        initColorConversionCache();
+        List<String> colorantNames = getColorantNames();
+        initColorConversionCache(colorantNames);
 
         // set initial color space
-        int n = getNumberOfComponents();
+        int n = colorantNames.size();
         float[] initial = new float[n];
         for (int i = 0; i < n; i++)
         {
@@ -106,7 +107,7 @@ public class PDDeviceN extends PDSpecialColorSpace
     }
 
     // initializes the color conversion cache
-    private void initColorConversionCache() throws IOException
+    private void initColorConversionCache(List<String> colorantNames) throws IOException
     {
         // there's nothing to cache for non-attribute spaces
         if (attributes == null)
@@ -115,16 +116,10 @@ public class PDDeviceN extends PDSpecialColorSpace
         }
 
         // colorant names
-        List<String> colorantNames = getColorantNames();
         numColorants = colorantNames.size();
 
         // process components
         colorantToComponent = new int[numColorants];
-        for (int c = 0; c < numColorants; c++)
-        {
-            colorantToComponent[c] = -1;
-        }
-
         if (attributes.getProcess() != null)
         {
             List<String> components = attributes.getProcess().getComponents();
@@ -138,6 +133,13 @@ public class PDDeviceN extends PDSpecialColorSpace
             // process color space
             processColorSpace = attributes.getProcess().getColorSpace();
         }
+        else
+        {
+            for (int c = 0; c < numColorants; c++)
+            {
+                colorantToComponent[c] = -1;
+            }
+        }
 
         // spot colorants
         spotColorSpaces = new PDSeparation[numColorants];
@@ -221,12 +223,13 @@ public class PDDeviceN extends PDSpecialColorSpace
                 componentColorSpace = spotColorSpaces[c];
             }
 
+            int numberOfComponents = componentColorSpace.getNumberOfComponents();
             // copy single-component to its own raster in the component color space
             WritableRaster componentRaster = Raster.createBandedRaster(DataBuffer.TYPE_BYTE,
-                width, height, componentColorSpace.getNumberOfComponents(), new Point(0, 0));
+                width, height, numberOfComponents, new Point(0, 0));
 
             int[] samples = new int[numColorants];
-            int[] componentSamples = new int[componentColorSpace.getNumberOfComponents()];
+            int[] componentSamples = new int[numberOfComponents];
             boolean isProcessColorant = colorantToComponent[c] >= 0;
             int componentIndex = colorantToComponent[c];
             for (int y = 0; y < height; y++)
@@ -467,7 +470,7 @@ public class PDDeviceN extends PDSpecialColorSpace
      * Returns the list of colorants.
      * @return the list of colorants
      */
-    public List<String> getColorantNames()
+    public final List<String> getColorantNames()
     {
         COSArray names = (COSArray)array.getObject(COLORANT_NAMES);
         return COSArrayList.convertCOSNameCOSArrayToList(names);
