@@ -500,13 +500,14 @@ public final class PDImageXObject extends PDXObject implements PDImage
         if (softMask != null)
         {
             image = applyMask(SampledImageReader.getRGBImage(this, region, subsampling, getColorKeyMask()),
-                    softMask.getOpaqueImage(), softMask.getInterpolate(), true, extractMatte(softMask));
+                    softMask.getOpaqueImage(region, subsampling), softMask.getInterpolate(), true,
+                    extractMatte(softMask));
         }
         // explicit mask - to be applied only if /ImageMask true
         else if (mask != null && mask.isStencil())
         {
             image = applyMask(SampledImageReader.getRGBImage(this, region, subsampling, getColorKeyMask()),
-                    mask.getOpaqueImage(), mask.getInterpolate(), false, null);
+                    mask.getOpaqueImage(region, subsampling), mask.getInterpolate(), false, null);
         }
         else
         {
@@ -585,7 +586,25 @@ public final class PDImageXObject extends PDXObject implements PDImage
      */
     public BufferedImage getOpaqueImage() throws IOException
     {
-        return SampledImageReader.getRGBImage(this, null);
+        return getOpaqueImage(null, 1);
+    }
+
+    /**
+     * Returns an RGB buffered image containing the opaque image stream without any masks applied. If this Image XObject
+     * is a mask then the buffered image will contain the raw mask.
+     * 
+     * @param region The region of the source image to get, or null if the entire image is needed. The actual region
+     * will be clipped to the dimensions of the source image.
+     * 
+     * @param subsampling The amount of rows and columns to advance for every output pixel, a value of 1 meaning every
+     * pixel will be read. It must not be larger than the image width or height.
+     * 
+     * @return the image without any masks applied
+     * @throws IOException if the image cannot be read
+     */
+    public BufferedImage getOpaqueImage(Rectangle region, int subsampling) throws IOException
+    {
+        return SampledImageReader.getRGBImage(this, region, subsampling, null);
     }
 
     /**
