@@ -419,10 +419,11 @@ final class PNGConverter
     private static COSStream createCOSStreamwithIccProfile
         (PDDocument document, PDColorSpace colorSpace, PNGConverterState state) throws IOException
     {
+        int numberOfComponents = colorSpace.getNumberOfComponents();
         COSStream cosStream = document.getDocument().createCOSStream();
-        cosStream.setInt(COSName.N, colorSpace.getNumberOfComponents());
-        cosStream.setItem(COSName.ALTERNATE, colorSpace.getNumberOfComponents()
-                == 1 ? COSName.DEVICEGRAY : COSName.DEVICERGB);
+        cosStream.setInt(COSName.N, numberOfComponents);
+        cosStream.setItem(COSName.ALTERNATE, 
+                numberOfComponents == 1 ? COSName.DEVICEGRAY : COSName.DEVICERGB);
         cosStream.setItem(COSName.FILTER, COSName.FLATE_DECODE);
         if (state.iCCP != null)
         {
