@@ -226,20 +226,21 @@ public class PDVisibleSignDesigner
                 yAxis = pageHeight - xAxis - imageWidth;
                 xAxis = temp;
 
+                affineTransform = new AffineTransform(
+                        0, imageHeight / imageWidth, -imageWidth / imageHeight, 0, imageWidth, 0);
+
                 temp = imageHeight;
                 imageHeight = imageWidth;
                 imageWidth = temp;
-
-                affineTransform = new AffineTransform(0, 0.5, -2, 0, 100, 0);
                 break;
-                
+
             case 180:
                 float newX = pageWidth - xAxis - imageWidth;
                 float newY = pageHeight - yAxis - imageHeight;
                 xAxis = newX;
                 yAxis = newY;
-                
-                affineTransform = new AffineTransform(-1, 0, 0, -1, 100, 50);
+
+                affineTransform = new AffineTransform(-1, 0, 0, -1, imageWidth, imageHeight);
                 break;
 
             case 270:
@@ -247,11 +248,12 @@ public class PDVisibleSignDesigner
                 xAxis = pageWidth - yAxis - imageHeight;
                 yAxis = temp;
 
+                affineTransform = new AffineTransform(
+                        0, -imageHeight / imageWidth, imageWidth / imageHeight, 0, 0, imageHeight);
+
                 temp = imageHeight;
                 imageHeight = imageWidth;
                 imageWidth = temp;
-
-                affineTransform = new AffineTransform(0, -0.5, 2, 0, 0, 50);
                 break;
 
             case 0:
