@@ -128,12 +128,12 @@ class AppearanceGeneratorHelper {
         // add font resources which might be available at the field
         // level but are not at the AcroForm level to the AcroForm
         // to match Adobe Reader/Acrobat behavior
-        if (field.getAcroForm().getDefaultResources() == null) {
+        PDResources acroFormResources = field.getAcroForm().getDefaultResources();
+        if (acroFormResources == null)
+        {
             return;
         }
 
-        PDResources acroFormResources = field.getAcroForm().getDefaultResources();
-
         for (PDAnnotationWidget widget : field.getWidgets())
         {
             PDAppearanceStream stream = widget.getNormalAppearanceStream();
@@ -455,8 +455,9 @@ class AppearanceGeneratorHelper {
         if (widget.getBorderStyle() != null) {
             borderWidth = widget.getBorderStyle().getWidth();
         }
-        PDRectangle clipRect = applyPadding(bbox, Math.max(1f, borderWidth));
-        PDRectangle contentRect = applyPadding(clipRect, Math.max(1f, borderWidth));
+        float padding = Math.max(1f, borderWidth);
+        PDRectangle clipRect = applyPadding(bbox, padding);
+        PDRectangle contentRect = applyPadding(clipRect, padding);
 
         contents.saveGraphicsState();
 
@@ -623,8 +624,12 @@ class AppearanceGeneratorHelper {
      * @return the comb state
      */
     private boolean shallComb() {
-        return field instanceof PDTextField && ((PDTextField) field).isComb() && !((PDTextField) field).isMultiline()
-                && !((PDTextField) field).isPassword() && !((PDTextField) field).isFileSelect();
+        return field instanceof PDTextField && 
+                ((PDTextField) field).isComb() &&
+                ((PDTextField) field).getMaxLen() != -1 &&
+                !((PDTextField) field).isMultiline() &&
+                !((PDTextField) field).isPassword() &&
+                !((PDTextField) field).isFileSelect();
     }
 
     /**
@@ -680,25 +685,27 @@ class AppearanceGeneratorHelper {
     }
 
     private void insertGeneratedListboxSelectionHighlight(PDPageContentStream contents,
-            PDAppearanceStream appearanceStream, PDFont font, float fontSize) throws IOException {
-        List<Integer> indexEntries = ((PDListBox) field).getSelectedOptionsIndex();
-        List<String> values = ((PDListBox) field).getValue();
-        List<String> options = ((PDListBox) field).getOptionsExportValues();
+            PDAppearanceStream appearanceStream, PDFont font, float fontSize) throws IOException
+    {
+        PDListBox listBox = (PDListBox) field;
+        List<Integer> indexEntries = listBox.getSelectedOptionsIndex();
+        List<String> values = listBox.getValue();
+        List<String> options = listBox.getOptionsExportValues();
 
-        if (!values.isEmpty() && !options.isEmpty() && indexEntries.isEmpty()) {
+        if (!values.isEmpty() && !options.isEmpty() && indexEntries.isEmpty())
+        {
             // create indexEntries from options
-            indexEntries = new ArrayList<Integer>();
-            for (String v : values) {
+            indexEntries = new ArrayList<Integer>(values.size());
+            for (String v : values)
+            {
                 indexEntries.add(options.indexOf(v));
             }
         }
 
-        // The first entry which shall be presented might be adjusted by the optional TI
-        // key
-        // If this entry is present the first entry to be displayed is the keys value
-        // otherwise
-        // display starts with the first entry in Opt.
-        int topIndex = ((PDListBox) field).getTopIndex();
+        // The first entry which shall be presented might be adjusted by the optional TI key
+        // If this entry is present, the first entry to be displayed is the keys value,
+        // otherwise display starts with the first entry in Opt.
+        int topIndex = listBox.getTopIndex();
 
         float highlightBoxHeight = font.getBoundingBox().getHeight() * fontSize / FONTSCALE;
 
@@ -742,13 +749,15 @@ class AppearanceGeneratorHelper {
         float yTextPos = contentRect.getUpperRightY();
 
         int topIndex = ((PDListBox) field).getTopIndex();
+        float ascent = font.getFontDescriptor().getAscent();
+        float height = font.getBoundingBox().getHeight();
 
         for (int i = topIndex; i < numOptions; i++) {
 
             if (i == topIndex) {
-                yTextPos = yTextPos - font.getFontDescriptor().getAscent() / FONTSCALE * fontSize;
+                yTextPos = yTextPos - ascent / FONTSCALE * fontSize;
             } else {
-                yTextPos = yTextPos - font.getBoundingBox().getHeight() / FONTSCALE * fontSize;
+                yTextPos = yTextPos - height / FONTSCALE * fontSize;
                 contents.beginText();
             }
 
