@@ -127,6 +127,10 @@ public class PageDrawer extends PDFGraphicsStreamEngine
 {
     private static final Log LOG = LogFactory.getLog(PageDrawer.class);
 
+    private static final String OS_NAME = System.getProperty("os.name").toLowerCase();
+    private static final boolean IS_WINDOWS = OS_NAME.startsWith("windows");
+    private static final boolean IS_LINUX = OS_NAME.startsWith("linux");
+
     // parent document renderer - note: this is needed for not-yet-implemented resource caching
     private final PDFRenderer renderer;
     
@@ -530,7 +534,8 @@ public class PageDrawer extends PDFGraphicsStreamEngine
             if (!font.isEmbedded() && !font.isVertical() && !font.isStandard14() && font.hasExplicitWidth(code))
             {
                 float fontWidth = font.getWidthFromFont(code);
-                if (fontWidth > 0 && // ignore spaces
+                if (displacement.getX() > 0 && // PDFBOX-5611: ignore zero widths
+                        fontWidth > 0 && // ignore spaces
                         Math.abs(fontWidth - displacement.getX() * 1000) > 0.0001)
                 {
                     float pdfWidth = displacement.getX() * 1000;
@@ -822,9 +827,8 @@ public class PageDrawer extends PDFGraphicsStreamEngine
     private float[] getDashArray(PDLineDashPattern dashPattern)
     {
         float[] dashArray = dashPattern.getDashArray();
-        int phase = dashPattern.getPhase();
         // avoid empty, infinite and NaN values (PDFBOX-3360)
-        if (dashArray.length == 0 || Float.isInfinite(phase) || Float.isNaN(phase))
+        if (dashArray.length == 0)
         {
             return null;
         }
@@ -1142,21 +1146,8 @@ public class PageDrawer extends PDFGraphicsStreamEngine
                 Paint paint = getNonStrokingPaint();
                 Rectangle2D unitRect = new Rectangle2D.Float(0, 0, 1, 1);
                 Rectangle2D bounds = at.createTransformedShape(unitRect).getBounds2D();
-                GraphicsConfiguration deviceConfiguration = graphics.getDeviceConfiguration();
-                int w;
-                int h;
-                if (deviceConfiguration != null && deviceConfiguration.getBounds() != null)
-                {
-                    // PDFBOX-4690: bounds doesn't need to be larger than device bounds (OOM risk)
-                    Rectangle deviceBounds = deviceConfiguration.getBounds();
-                    w = (int) Math.ceil(Math.min(bounds.getWidth(), deviceBounds.getWidth()));
-                    h = (int) Math.ceil(Math.min(bounds.getHeight(), deviceBounds.getHeight()));
-                }
-                else
-                {
-                    w = (int) Math.ceil(bounds.getWidth());
-                    h = (int) Math.ceil(bounds.getHeight());
-                }
+                int w = (int) Math.ceil(bounds.getWidth());
+                int h = (int) Math.ceil(bounds.getHeight());
                 BufferedImage renderedPaint = new BufferedImage(w, h, BufferedImage.TYPE_INT_ARGB);
                 Graphics2D g = (Graphics2D) renderedPaint.getGraphics();
                 g.translate(-bounds.getMinX(), -bounds.getMinY());
@@ -1277,15 +1268,15 @@ public class PageDrawer extends PDFGraphicsStreamEngine
     }
 
     /**
-     * Calculated the subsampling frequency for a given PDImage based on the current transformation
-     * and its calculated transform
+     * Calculates the subsampling frequency for a given PDImage based on the current transformation
+     * and its calculated transform. Extend this method if you want to use your own strategy.
      *
      * @param pdImage PDImage to be drawn
      * @param at Transform that will be applied to the image when drawing
      * @return The rounded-down ratio of image pixels to drawn pixels. Returned value will always be
-     * >=1.
+     * &gt;=1.
      */
-    private int getSubsampling(PDImage pdImage, AffineTransform at)
+    protected int getSubsampling(PDImage pdImage, AffineTransform at)
     {
         // calculate subsampling according to the resulting image size
         double scale = Math.abs(at.getDeterminant() * xform.getDeterminant());
@@ -1373,6 +1364,29 @@ public class PageDrawer extends PDFGraphicsStreamEngine
             }
             else
             {
+                GraphicsConfiguration graphicsConfiguration = graphics.getDeviceConfiguration();
+                int deviceType = GraphicsDevice.TYPE_RASTER_SCREEN;
+                if (graphicsConfiguration != null)
+                {
+                    GraphicsDevice graphicsDevice = graphicsConfiguration.getDevice();
+                    if (graphicsDevice != null)
+                    {
+                        deviceType = graphicsDevice.getType();
+                    }
+                }
+                if (deviceType == GraphicsDevice.TYPE_PRINTER &&
+                    image.getType() != BufferedImage.TYPE_4BYTE_ABGR &&
+                    (IS_WINDOWS || IS_LINUX))
+                {
+                    // PDFBOX-5601, PDFBOX-4010, JDK-8308099, JDK-8191800:
+                    // workaround to avoid terrible / missing output on printer unless TYPE_4BYTE_ABGR
+                    BufferedImage bim = new BufferedImage(
+                            image.getWidth(), image.getHeight(), BufferedImage.TYPE_4BYTE_ABGR);
+                    Graphics g = bim.getGraphics();
+                    g.drawImage(image, 0, 0, null);
+                    g.dispose();
+                    image = bim;
+                }
                 graphics.drawImage(image, imageTransform, null);
             }
         }
@@ -2024,11 +2038,11 @@ public class PageDrawer extends PDFGraphicsStreamEngine
             nestedHiddenOCGCount++;
             return;
         }
-        if (tag == null || getPage().getResources() == null)
+        if (tag == null || getResources() == null)
         {
             return;
         }
-        if (isHiddenOCG(getPage().getResources().getProperties(tag)))
+        if (isHiddenOCG(getResources().getProperties(tag)))
         {
             nestedHiddenOCGCount = 1;
         }
