@@ -53,6 +53,8 @@ public abstract class TestCOSNumber extends TestCOSBase
         {
             // Ensure the basic static numbers are recognized
             assertEquals(COSInteger.ZERO, COSNumber.get("0"));
+            assertEquals(COSInteger.ZERO, COSNumber.get("-"));
+            assertEquals(COSInteger.ZERO, COSNumber.get("."));
             assertEquals(COSInteger.ONE, COSNumber.get("1"));
             assertEquals(COSInteger.TWO, COSNumber.get("2"));
             assertEquals(COSInteger.THREE, COSNumber.get("3"));
@@ -78,6 +80,15 @@ public abstract class TestCOSNumber extends TestCOSBase
             {
                 // PASS
             }
+            try
+            {
+                assertEquals(0, COSNumber.get("a"));
+                fail("Failed to throw an IOException");
+            }
+            catch (IOException e)
+            {
+                // PASS
+            }
             // PDFBOX-2569: some numbers start with "+"
             assertEquals(COSNumber.get("1"), COSNumber.get("+1"));
             assertEquals(COSNumber.get("123"), COSNumber.get("+123"));
