@@ -97,7 +97,7 @@ public class TestSymmetricKeyEncryption extends TestCase
         permission.setCanModify(false);
         permission.setCanModifyAnnotations(false);
         permission.setCanPrint(true);
-        permission.setCanPrintDegraded(false);
+        permission.setCanPrintFaithful(false);
         permission.setReadOnly();
     }
 
@@ -133,7 +133,7 @@ public class TestSymmetricKeyEncryption extends TestCase
 
         restrAP.setCanAssembleDocument(false);
         restrAP.setCanExtractForAccessibility(false);
-        restrAP.setCanPrintDegraded(false);
+        restrAP.setCanPrintFaithful(false);
 
         inputFileAsByteArray = getFileResourceAsByteArray("PasswordSample-128bit.pdf");
         checkPerms(inputFileAsByteArray, "owner", fullAP);
@@ -182,7 +182,7 @@ public class TestSymmetricKeyEncryption extends TestCase
         assertEquals(expectedPermissions.canModify(), currentAccessPermission.canModify());
         assertEquals(expectedPermissions.canModifyAnnotations(), currentAccessPermission.canModifyAnnotations());
         assertEquals(expectedPermissions.canPrint(), currentAccessPermission.canPrint());
-        assertEquals(expectedPermissions.canPrintDegraded(), currentAccessPermission.canPrintDegraded());
+        assertEquals(expectedPermissions.canPrintFaithful(), currentAccessPermission.canPrintFaithful());
 
         new PDFRenderer(doc).renderImage(0);
 
