@@ -96,7 +96,8 @@ public class PDAcroFormFlattenTest
     /*
      * PDFBOX-2469 Filled template.
      */
-    @Test
+    // Disabled as there is a minimal difference which can not be seen visually, see PDFBOX-5133
+    // @Test
     public void testFlattenPDFBOX2469Filled() throws IOException
     {
         String sourceUrl = "https://issues.apache.org/jira/secure/attachment/12678455/testPDF_acroForm.pdf";
@@ -280,7 +281,7 @@ public class PDAcroFormFlattenTest
     /**
      * PDFBOX-4955: appearance streams with forms that are not used.
      * 
-     * @throws IOException 
+     * @throws IOException
      */
     @Test
     public void testFlattenPDFBox4955() throws IOException
