@@ -23,13 +23,16 @@ package org.apache.pdfbox.preflight;
 
 import java.io.Closeable;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 import javax.activation.DataSource;
 
 import org.apache.pdfbox.cos.COSBase;
 import org.apache.pdfbox.pdfparser.XrefTrailerResolver;
+import org.apache.pdfbox.pdmodel.common.COSObjectable;
 import org.apache.pdfbox.preflight.ValidationResult.ValidationError;
 import org.apache.pdfbox.preflight.font.container.FontContainer;
 import org.apache.pdfbox.preflight.graphic.ICCProfileWrapper;
@@ -77,6 +80,8 @@ public class PreflightContext implements Closeable
 
     private PreflightPath validationPath = new PreflightPath();
 
+    private final Set<COSObjectable> processedSet = new HashSet<COSObjectable>();
+
     private Integer currentPageNumber = null;
     
     private long fileLen;
@@ -288,4 +293,25 @@ public class PreflightContext implements Closeable
     {
         return fileLen;
     }
+
+    /**
+     * Add the argument to the set of processed elements,
+     *
+     * @param cos
+     */
+    public void addToProcessedSet(COSObjectable cos)
+    {
+        processedSet.add(cos);
+    }
+
+    /**
+     * Tell if the argument is in the set of processed elements.
+     *
+     * @param cos
+     * @return true if in the set, false if not.
+     */
+    public boolean isInProcessedSet(COSObjectable cos)
+    {
+        return processedSet.contains(cos);
+    }
 }
