@@ -246,7 +246,11 @@ public class CatalogValidationProcess extends AbstractProcess
         COSArray outputIntents = COSUtils.getAsArray(cBase, cosDocument);
 
         Map<COSObjectKey, Boolean> tmpDestOutputProfile = new HashMap<COSObjectKey, Boolean>();
-        for (int i = 0; outputIntents != null && i < outputIntents.size(); ++i)
+        if (outputIntents == null)
+        {
+            return;
+        }
+        for (int i = 0; i < outputIntents.size(); ++i)
         {
             COSDictionary outputIntentDict = COSUtils.getAsDictionary(outputIntents.get(i), cosDocument);
 
@@ -326,11 +330,6 @@ public class CatalogValidationProcess extends AbstractProcess
             {
         try
         {
-            if (destOutputProfile == null)
-            {
-                return;
-            }
-
             // destOutputProfile should be an instance of COSObject because of this is a object reference
             if (destOutputProfile instanceof COSObject)
             {
@@ -348,6 +347,12 @@ public class CatalogValidationProcess extends AbstractProcess
                 }
                 // else the profile will be kept in the tmpDestOutputProfile if it is valid
             }
+            else
+            {
+                addValidationError(ctx, new ValidationError(ERROR_GRAPHIC_OUTPUT_INTENT_INVALID_ENTRY,
+                        "OutputIntent object should be a reference: " + destOutputProfile));
+                return;
+            }
 
             // keep reference to avoid multiple profile definition
             mapDestOutputProfile.put(new COSObjectKey((COSObject) destOutputProfile), true);
@@ -383,6 +388,12 @@ public class CatalogValidationProcess extends AbstractProcess
             addValidationError(ctx, new ValidationError(ERROR_GRAPHIC_OUTPUT_INTENT_ICC_PROFILE_INVALID,
                     "DestOutputProfile isn't a valid ICCProfile: " + e.getMessage(), e));
         }
+        catch (ArrayIndexOutOfBoundsException e)
+        {
+            // this is not a ICC_Profile
+            addValidationError(ctx, new ValidationError(ERROR_GRAPHIC_OUTPUT_INTENT_ICC_PROFILE_INVALID,
+                    "DestOutputProfile isn't a valid ICCProfile: " + e.getMessage(), e));
+        }
         catch (IOException e)
         {
             throw new ValidationException("Unable to parse the ICC Profile.", e);
