@@ -16,6 +16,7 @@
 package org.apache.pdfbox.tools;
 
 import java.io.File;
+import java.io.IOException;
 
 import org.apache.pdfbox.cos.COSName;
 import org.apache.pdfbox.cos.COSObject;
@@ -95,7 +96,7 @@ public final class DecompressObjectstreams
             }
             doc.save(outputFilename);
         }
-        catch(Exception e) 
+        catch (IOException e)
         {
             System.err.println("Error processing file: " + e.getMessage());
         }
