@@ -141,27 +141,27 @@ public final class TypeMapping
         }
         catch (InvocationTargetException e)
         {
-            throw new BadFieldValueException("Failed to instanciate structured type : " + type, e);
+            throw new BadFieldValueException("Failed to instantiate structured type : " + type, e);
         }
         catch (IllegalArgumentException e)
         {
-            throw new BadFieldValueException("Failed to instanciate structured type : " + type, e);
+            throw new BadFieldValueException("Failed to instantiate structured type : " + type, e);
         }
         catch (InstantiationException e)
         {
-            throw new BadFieldValueException("Failed to instanciate structured type : " + type, e);
+            throw new BadFieldValueException("Failed to instantiate structured type : " + type, e);
         }
         catch (IllegalAccessException e)
         {
-            throw new BadFieldValueException("Failed to instanciate structured type : " + type, e);
+            throw new BadFieldValueException("Failed to instantiate structured type : " + type, e);
         }
         catch (SecurityException e)
         {
-            throw new BadFieldValueException("Failed to instanciate structured type : " + type, e);
+            throw new BadFieldValueException("Failed to instantiate structured type : " + type, e);
         }
         catch (NoSuchMethodException e)
         {
-            throw new BadFieldValueException("Failed to instanciate structured type : " + type, e);
+            throw new BadFieldValueException("Failed to instantiate structured type : " + type, e);
         }
     }
 
@@ -185,31 +185,31 @@ public final class TypeMapping
         }
         catch (NoSuchMethodError e)
         {
-            throw new IllegalArgumentException("Failed to instanciate " + clz.getSimpleName() + " property with value " + value, e);
+            throw new IllegalArgumentException("Failed to instantiate " + clz.getSimpleName() + " property with value " + value, e);
         }
         catch (IllegalArgumentException e)
         {
-            throw new IllegalArgumentException("Failed to instanciate " + clz.getSimpleName() + " property with value " + value, e);
+            throw new IllegalArgumentException("Failed to instantiate " + clz.getSimpleName() + " property with value " + value, e);
         }
         catch (InstantiationException e)
         {
-            throw new IllegalArgumentException("Failed to instanciate " + clz.getSimpleName() + " property with value " + value, e);
+            throw new IllegalArgumentException("Failed to instantiate " + clz.getSimpleName() + " property with value " + value, e);
         }
         catch (IllegalAccessException e)
         {
-            throw new IllegalArgumentException("Failed to instanciate " + clz.getSimpleName() + " property with value " + value, e);
+            throw new IllegalArgumentException("Failed to instantiate " + clz.getSimpleName() + " property with value " + value, e);
         }
         catch (InvocationTargetException e)
         {
-            throw new IllegalArgumentException("Failed to instanciate " + clz.getSimpleName() + " property with value " + value, e);
+            throw new IllegalArgumentException("Failed to instantiate " + clz.getSimpleName() + " property with value " + value, e);
         }
         catch (SecurityException e)
         {
-            throw new IllegalArgumentException("Failed to instanciate " + clz.getSimpleName() + " property with value " + value, e);
+            throw new IllegalArgumentException("Failed to instantiate " + clz.getSimpleName() + " property with value " + value, e);
         }
         catch (NoSuchMethodException e)
         {
-            throw new IllegalArgumentException("Failed to instanciate " + clz.getSimpleName() + " property with value " + value, e);
+            throw new IllegalArgumentException("Failed to instantiate " + clz.getSimpleName() + " property with value " + value, e);
         }
     }
 
